@@ -7,8 +7,8 @@ use crate::{
     },
     esdt::ESDTSystemSmartContractProxy,
     types::{
-        AsManagedRef, BigUint, ContractCall, EsdtTokenPayment, ManagedAddress, ManagedArgBuffer,
-        ManagedBuffer, ManagedInto, ManagedVec, TokenIdentifier,
+        BigUint, ContractCall, EsdtTokenPayment, ManagedAddress, ManagedArgBuffer, ManagedBuffer,
+        ManagedInto, ManagedVec, TokenIdentifier,
     },
 };
 use elrond_codec::TopDecode;
@@ -319,7 +319,7 @@ where
         );
 
         if let Some(first_result_bytes) = output.get(0) {
-            u64::top_decode(first_result_bytes.as_managed_ref()).unwrap_or_default()
+            u64::top_decode(first_result_bytes).unwrap_or_default()
         } else {
             0
         }
