@@ -3,11 +3,11 @@ use super::{QueueMapper, StorageClearable, StorageMapper};
 use crate::{
     abi::{TypeAbi, TypeDescriptionContainer, TypeName},
     api::{EndpointFinishApi, ErrorApi, ManagedTypeApi, StorageReadApi, StorageWriteApi},
+    finish_all,
     io::EndpointResult,
     storage::{storage_get, storage_set, StorageKey},
     types::MultiResultVec,
 };
-use alloc::vec::Vec;
 use elrond_codec::{NestedDecode, NestedEncode, TopDecode, TopEncode};
 
 const NULL_ENTRY: u32 = 0;
@@ -150,8 +150,7 @@ where
     where
         FA: ManagedTypeApi + EndpointFinishApi + Clone + 'static,
     {
-        let v: Vec<T> = self.iter().collect();
-        MultiResultVec::<T>::from(v).finish(api);
+        finish_all(api, self.iter());
     }
 }
 
