@@ -8,6 +8,7 @@ mod big_uint_operators;
 mod elliptic_curve;
 mod managed_address;
 mod managed_buffer;
+mod managed_buffer_cached_builder;
 mod managed_byte_array;
 mod managed_conversion;
 mod managed_default;
@@ -19,6 +20,7 @@ mod managed_type_trait;
 mod managed_vec;
 mod managed_vec_item;
 mod managed_vec_iter;
+pub(crate) mod preloaded_managed_buffer;
 
 pub use big_int::BigInt;
 pub use big_int_sign::Sign;
@@ -26,6 +28,7 @@ pub use big_uint::BigUint;
 pub use elliptic_curve::{EllipticCurve, EllipticCurveComponents};
 pub use managed_address::ManagedAddress;
 pub use managed_buffer::ManagedBuffer;
+pub use managed_buffer_cached_builder::ManagedBufferCachedBuilder;
 pub(crate) use managed_byte_array::ManagedBufferSizeContext;
 pub use managed_byte_array::ManagedByteArray;
 pub use managed_conversion::{ManagedFrom, ManagedInto};
